# pyticketfood

The `pyticketfood` package is a simple wrapper to fetch transactions from Ticket food card.

# TODO

[ ] add simple CLI tool to show current balance and transactions
[ ] create pypi package
[ ] test login unsuccessfull, creds wrong (NOTE - ALL SUCCESSFULL TESTS REQUIRE VALID CRED)
[ ] test login successfull
[ ] test balance
[ ] test transactions